import * as i0 from '@angular/core';
import { signal, input, booleanAttribute, computed, effect, inject, ElementRef, Directive, HostBinding, Input, Component, NgModule } from '@angular/core';
import * as i1 from '@sowatech/shared/logger';
import { LoggerService } from '@sowatech/shared/logger';
import * as i2 from '@sowatech/shared/shared-config';
import { SharedConfigService } from '@sowatech/shared/shared-config';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { MessageBoxService } from '@sowatech/shared/dialogs';
import { I18nService } from '@sowatech/shared/utilities';

/* eslint-disable @angular-eslint/no-input-rename */
class ButtonBaseDirective {
    constructor(logger = inject(LoggerService), el = inject((ElementRef)), renderer, config = inject(SharedConfigService)) {
        this.logger = logger;
        this.el = el;
        this.renderer = renderer;
        this.config = config;
        this.iconSignal = signal('');
        this.btnClassSignal = signal('');
        this.faTypeSignal = signal('fa');
        this.disableMargin = input(false, { transform: booleanAttribute });
        this.marginClass = computed(() => this.disableMargin() ? '' : (this.config.templateKey === 'inspinia' ? 'm-r-xs' : 'me-1'));
        effect(() => this.setHostClasses());
    }
    setHostClasses() {
        this.class = `btn btn-${this.btnClassSignal()} ${this.config.btnSize} ${this.marginClass()}`;
    }
    //#region Abwärtskompatibilität
    set icon(value) {
        this.iconSignal.set(value);
    }
    get icon() { return this.iconSignal(); }
    set btnClass(value) {
        this.btnClassSignal.set(value);
    }
    get btnClass() { return this.btnClassSignal(); }
    set faType(value) {
        this.faTypeSignal.set(value);
    }
    get faType() { return this.faTypeSignal(); }
    // eslint-disable-next-line @angular-eslint/no-empty-lifecycle-method,@typescript-eslint/no-empty-function
    ngOnInit() { }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonBaseDirective, deps: [{ token: i1.LoggerService }, { token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i2.SharedConfigService }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "17.1.0", version: "17.3.9", type: ButtonBaseDirective, inputs: { disableMargin: { classPropertyName: "disableMargin", publicName: "disableMargin", isSignal: true, isRequired: false, transformFunction: null }, icon: { classPropertyName: "icon", publicName: "icon", isSignal: false, isRequired: false, transformFunction: null }, btnClass: { classPropertyName: "btnClass", publicName: "btn-class", isSignal: false, isRequired: false, transformFunction: null }, faType: { classPropertyName: "faType", publicName: "fa-type", isSignal: false, isRequired: false, transformFunction: null } }, host: { properties: { "class": "this.class" } }, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonBaseDirective, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: i1.LoggerService }, { type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i2.SharedConfigService }], propDecorators: { class: [{
                type: HostBinding,
                args: ['class']
            }], icon: [{
                type: Input
            }], btnClass: [{
                type: Input,
                args: ['btn-class']
            }], faType: [{
                type: Input,
                args: ['fa-type']
            }] } });

class ButtonAddComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.iconSignal.set('plus');
        this.btnClassSignal.set('default');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonAddComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonAddComponent, selector: "button[button-add]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonAddComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-add]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

const CLASS = 'ButtonConfirmDirective';
class ButtonConfirmDirective extends ButtonBaseDirective {
    constructor(i18nService = inject(I18nService), messageBoxService = inject(MessageBoxService)) {
        super();
        this.i18nService = i18nService;
        this.messageBoxService = messageBoxService;
        this.designation = ''; // z.B. Person
        this.name = ''; // z.B. Chris König
        this.confirmDialog = true;
        this.nativeClickListeners = [];
    }
    ngOnInit() {
        super.ngOnInit();
        for (const listener of this.el.nativeElement.eventListeners()) {
            this.nativeClickListeners.push(listener);
            this.el.nativeElement.removeEventListener('click', listener);
        }
        this.el.nativeElement.addEventListener('click', event => this.doClick(event));
    }
    async doClick(e) {
        const confirmed = await this.showConfirmDialog();
        if (confirmed)
            this.nativeClickListeners.forEach(listener => listener(e));
    }
    async showConfirmDialog() {
        if (!this.confirmDialog)
            return true;
        const text = this.getText();
        if (text == null) {
            this.logger.error(CLASS + ' needs a confirmationText, a name or a designation');
            return false;
        }
        await this.messageBoxService.confirmDialog(text, this.confirmationTitle);
        return true;
    }
    getText() {
        if (this.confirmationText)
            return this.confirmationText;
        if (this.name && this.designation)
            return this.i18nService.replace(this.defaultText_designationAndName, [this.designation, this.name]);
        else if (this.name)
            return this.i18nService.replace(this.defaultText_name, [this.name]);
        else if (this.designation)
            return this.i18nService.replace(this.defaultText_designation, [this.designation]);
        return null;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonConfirmDirective, deps: "invalid", target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "17.3.9", type: ButtonConfirmDirective, inputs: { designation: "designation", name: "name", confirmationText: "confirmationText", confirmationTitle: "confirmationTitle", confirmDialog: "confirmDialog" }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonConfirmDirective, decorators: [{
            type: Directive
        }], ctorParameters: () => [{ type: undefined }, { type: undefined }], propDecorators: { designation: [{
                type: Input
            }], name: [{
                type: Input
            }], confirmationText: [{
                type: Input
            }], confirmationTitle: [{
                type: Input
            }], confirmDialog: [{
                type: Input
            }] } });

class ButtonCreateComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.iconSignal.set('plus');
        this.btnClassSignal.set('primary');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonCreateComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonCreateComponent, selector: "button[button-create]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonCreateComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-create]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonCustomComponent extends ButtonBaseDirective {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonCustomComponent, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonCustomComponent, selector: "button[button-custom]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonCustomComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-custom]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }] });

class ButtonDeleteComponent extends ButtonConfirmDirective {
    constructor() {
        super();
        this.iconSignal.set('trash');
        this.btnClassSignal.set('danger');
        this.confirmationTitle = $localize `:@@DeleteButton.act.Label:Löschen`;
        this.defaultText_designationAndName = $localize `:@@DeleteButton.confirmDialog.designationAndName.dsp.Text:$0 '$1' löschen?`;
        this.defaultText_designation = $localize `:@@DeleteButton.confirmDialog.designation.dsp.Text:$0 löschen?`;
        this.defaultText_name = $localize `:@@DeleteButton.confirmDialog.name.dsp.Text:'$0' löschen?`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonDeleteComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonDeleteComponent, selector: "button[button-delete]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonDeleteComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-delete]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonEditComponent extends ButtonBaseDirective {
    constructor() {
        super();
        this.iconSignal.set('edit');
        this.btnClassSignal.set('default');
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonEditComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonEditComponent, selector: "button[button-edit]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonEditComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-edit]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonRemoveComponent extends ButtonConfirmDirective {
    constructor() {
        super();
        this.iconSignal.set('unlink');
        this.btnClassSignal.set('danger');
        this.confirmationTitle = $localize `:@@RemoveButton.act.Label:Entfernen`;
        this.defaultText_designationAndName = $localize `:@@RemoveButton.confirmDialog.designationAndName.dsp.Text:$0 '$1' entfernen?`;
        this.defaultText_designation = $localize `:@@RemoveButton.confirmDialog.designation.dsp.Text:$0 entfernen?`;
        this.defaultText_name = $localize `:@@RemoveButton.confirmDialog.name.dsp.Text:'$0' entfernen?`;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonRemoveComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "17.3.9", type: ButtonRemoveComponent, selector: "button[button-remove]", usesInheritance: true, ngImport: i0, template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonRemoveComponent, decorators: [{
            type: Component,
            args: [{ selector: 'button[button-remove]', template: "<i class=\"{{faTypeSignal()}} fa-{{iconSignal()}}\" *ngIf=\"iconSignal()\"></i>\r\n<span class=\"button-content\"><ng-content></ng-content></span>\r\n", styles: ["span.button-content{margin-left:3px}span.button-content:empty,span.button-content:only-child{margin-left:0}\n"] }]
        }], ctorParameters: () => [] });

class ButtonsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "17.3.9", ngImport: i0, type: ButtonsModule, declarations: [ButtonAddComponent,
            ButtonCreateComponent,
            ButtonCustomComponent,
            ButtonDeleteComponent,
            ButtonEditComponent,
            ButtonRemoveComponent], imports: [CommonModule], exports: [ButtonAddComponent,
            ButtonCreateComponent,
            ButtonCustomComponent,
            ButtonDeleteComponent,
            ButtonEditComponent,
            ButtonRemoveComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonsModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.9", ngImport: i0, type: ButtonsModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                    ],
                    exports: [
                        ButtonAddComponent,
                        ButtonCreateComponent,
                        ButtonCustomComponent,
                        ButtonDeleteComponent,
                        ButtonEditComponent,
                        ButtonRemoveComponent,
                    ],
                    declarations: [
                        ButtonAddComponent,
                        ButtonCreateComponent,
                        ButtonCustomComponent,
                        ButtonDeleteComponent,
                        ButtonEditComponent,
                        ButtonRemoveComponent,
                    ],
                    providers: [],
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonAddComponent, ButtonBaseDirective, ButtonConfirmDirective, ButtonCreateComponent, ButtonCustomComponent, ButtonDeleteComponent, ButtonEditComponent, ButtonRemoveComponent, ButtonsModule };
//# sourceMappingURL=sowatech-shared-buttons.mjs.map
